@@ -21,10 +21,10 @@ renv::activate(project = paste0(RootPath,"/Data_acquisition_workflow"))
 install.packages("BeeBDC")
 # You could also install BeeBDC's development version using the below: 
 # WARNING the development version may not pass all CRAN or GitHub tests.
-    # remotes::install_github("https://github.com/jbdorey/BeeBDC.git", user="jbdorey", 
-    #                           # To use the development version, do below, otherwise choose "main"
-    #                         ref = "devel", 
-    #                         force = TRUE)
+     remotes::install_github("https://github.com/jbdorey/BeeBDC.git", user="jbdorey", 
+                               # To use the development version, do below, otherwise choose "main"
+                             ref = "devel", 
+                             force = TRUE)
 
 ##### 0.2 Load packages ####
 # Save a snapshot of the environment
@@ -54,7 +54,7 @@ BeeBDC::atlasDownloader(path = DataPath,
 # Supply the path to where the data are
 # save_type is either "csv_files" or "R_file"
 DataImp <- BeeBDC::repoMerge(path = DataPath, 
-                        # Find data — Many problems can be solved by running repoFinder(path = DataPath)
+                        # Find data - Many problems can be solved by running repoFinder(path = DataPath)
                         # And looking for problems
                       occ_paths = BeeBDC::repoFinder(path = DataPath),
                       save_type = "R_file")
@@ -107,7 +107,7 @@ rm(Complete_data, DataImp, USGS_data)
 ###### a. bdc import ####
 warning(paste0("The bdc method here is not truly implemented and supported. If you use it you must do so alone.",
                " This is just a place-holder for people using the bdc package more heavily.",
-               "\nPreferably, go directly to 2.1b — BeeBDC import."))
+               "\nPreferably, go directly to 2.1b - BeeBDC import."))
 # Read in the bdc metadata
 bdc_metadata <- readr::read_csv(paste(DataPath, "Output", "bdc_integration.csv", sep = "/"))
 # Standardise the dataset to bdc
@@ -143,7 +143,7 @@ db_standardized <- readr::read_csv(occPath,
 ##### 2.2 Paige dataset ####
 # Integrate Paige Chesshire's cleaned dataset.
 # Import Paige's cleaned N. American data
-# IF you haven't figured out by now, dont worry about the column name warning — not all columns occur here.
+# IF you haven't figured out by now, dont worry about the column name warning - not all columns occur here.
 PaigeNAm <- readr::read_csv(paste(DataPath, "Paige_data", "NorAmer_highQual_only_ALLfamilies.csv",
                                   sep = "/"), col_types = BeeBDC::ColTypeR()) %>%
   # Change the column name from Source to dataSource to match the rest of the data.
@@ -264,7 +264,7 @@ Gai_Data <- BeeBDC::readr_BeeBDC(dataset = "Gai",
                       outFile = "jbd_Gai_data.csv",
                       dataLicense = "https://creativecommons.org/licenses/by-nc-sa/4.0/")
 ###### g. CAES ####
-# This is a little slower and will have a few date warnings — 215 failed to parse. 
+# This is a little slower and will have a few date warnings - 215 failed to parse. 
 CAES_Data <- BeeBDC::readr_BeeBDC(dataset = "CAES",
                                 path = paste0(DataPath, "/Additional_Datasets"),
                         inFile = "/InputDatasets/CT_BEE_DATA_FROM_PBI.xlsx",
@@ -320,8 +320,8 @@ Bal_Data <- BeeBDC::readr_BeeBDC(dataset = "Bal",
 
 ###### m. Palouse Lic ####
 # # *Attached: My canola data. I tried to get this in DarwinCore format. 
-# These data go with a manuscript currently under review. Here’s the bioRxiv version: 
-# https://www.biorxiv.org/content/10.1101/2021.12.06.471474v2. 
+# These data go with the manuscript published here: 
+# https://doi.org/10.1111/jen.13188 
 # These are the data I will be putting on SCAN. 
 # - Elinor Lichtenberg
 Lic_Data <- BeeBDC::readr_BeeBDC(dataset = "Lic",
@@ -394,7 +394,7 @@ db_standardized <- db_standardized %>%
     readr::read_csv(paste0(DataPath, "/Additional_Datasets", 
                            "/jbd_VicWam_Data.csv"), col_types = BeeBDC::ColTypeR())) %>% 
   # END bind_rows
-  suppressWarnings(classes = "warning") # End suppressWarnings — due to col_types
+  suppressWarnings(classes = "warning") # End suppressWarnings - due to col_types
 
 ##### 2.6 Match database_id ####
 # Try to match database IDs with prior runs.
@@ -419,7 +419,7 @@ db_standardized <- idMatchR(
                         # Because INHS was entered as it's own dataset but is now included in the GBIF download...
                         c("catalogNumber", "institutionCode", "dataSource",
                           "decimalLatitude","decimalLongitude")),
-  # You can exclude datasets from prior by matching their prefixs — before first underscore:
+  # You can exclude datasets from prior by matching their prefixs - before first underscore:
   excludeDataset = c("ASP", "BMin", "BMont", "CAES", "EaCO", "Ecd", "EcoS",
                      "Gai", "KP", "EPEL", "CAES", "EaCO", "FSCA", "SMC", "Lic", "Arm",
                      "VicWam"))
@@ -440,7 +440,7 @@ if(!exists("db_standardized")){
   db_standardized <- readr::read_csv(paste(OutPath_Intermediate, "00_prefilter_database.csv",
                                     sep = "/"), col_types = BeeBDC::ColTypeR())}
 
-# See here for bdc prefilter tutorial — https://brunobrr.github.io/bdc/articles/prefilter.html
+# See here for bdc prefilter tutorial - https://brunobrr.github.io/bdc/articles/prefilter.html
 ##### 3.1 SciName ####
   # Flag occurrences without scientificName provided
 check_pf <- bdc::bdc_scientificName_empty(
@@ -684,7 +684,7 @@ flagFile <- BeeBDC::flagRecorder(
     # TRUE if you want to find a file from a previous part of the script to append to
   append = FALSE)
 
-# produce the .summary column in main dataset — will be FALSE if ANY .filtering column is FALSE
+# produce the .summary column in main dataset - will be FALSE if ANY .filtering column is FALSE
 check_pf <- BeeBDC::summaryFun(
   data = check_pf,
     # Don't filter these columns (or NULL)
@@ -717,7 +717,7 @@ check_pf %>%
                             sep = "/"))
 
 #### 4.0 Taxonomy ####
-# See bdc tutorial here — https://brunobrr.github.io/bdc/articles/taxonomy.html
+# See bdc tutorial here - https://brunobrr.github.io/bdc/articles/taxonomy.html
 if(!exists("check_pf")){
 # Read in the filtered dataset
 database <-
@@ -740,7 +740,7 @@ database <- database %>%
 # Flag and remove infraspecific terms (e.g., variety [var.], subspecies [subsp], forma [f.], and their spelling variations);
 # Standardize names, i.e., capitalize only the first letter of the genus name and remove extra whitespaces);
 # Parse names, i.e., separate author, date, annotations from taxon name.
-# ! MAC: You need to install gnparser through terminal — brew
+# ! MAC: You need to install gnparser through terminal - brew
   # brew tap gnames/gn
   # brew install gnparser
 parse_names <-
@@ -1040,7 +1040,7 @@ check_space %>%
 # .gbf == Records around the GBIF headquarters
 # .inst == Records around biodiversity institutions
 # .rou == Rounded (probably imprecise) coordinates
-# .urb == Records within urban areas — Not relevant for bees, I think.
+# .urb == Records within urban areas - Not relevant for bees, I think.
 # Example:
 figures$.rou
 
@@ -1089,7 +1089,7 @@ check_time$month <- ifelse(check_time$month > 12 | check_time$month < 1,
 check_time$day <- ifelse(check_time$day > 31 | check_time$day < 1,
                        NA, check_time$day)
 ##### 6.1 Recover dates ####
-# RESCUE some records with poor date data if possible — e.g., from other columns
+# RESCUE some records with poor date data if possible - e.g., from other columns
 check_time <- BeeBDC::dateFindR(data = check_time,
                         # Years above this are removed (from the recovered dates only)
                         maxYear = lubridate::year(Sys.Date()),
@@ -1182,7 +1182,7 @@ check_time <- BeeBDC::dupeSummary(
                      "recordedBy"),
   # The columns to combine, one-by-one with the collectionCols
   collectInfoColumns = c("catalogNumber", "otherCatalogNumbers"),
-    # Custom comparisons — as a list of columns to compare
+    # Custom comparisons - as a list of columns to compare
      # RAW custom comparisons do not use the character and number thresholds
   CustomComparisonsRAW = dplyr::lst(c("catalogNumber", "institutionCode", "scientificName")),
      # Other custom comparisons use the character and number thresholds
@@ -1241,7 +1241,7 @@ check_time <- manualOutlierFindeR(
   data = check_time,
   DataPath = DataPath,
   PaigeOutliersName = "removedBecauseDeterminedOutlier.csv",
-  newOutliersName = "^All_outliers_ANB_14March.xlsx",
+  newOutliersName = "^All_outliers_ANB_23Jan24.xlsx",
   ColombiaOutliers_all = "All_Colombian_OutlierIDs.csv",
   # A .csv with manual outlier records that are too close to otherwise TRUE records
   NearTRUE = "nearTRUE.csv",
@@ -1257,8 +1257,9 @@ check_time <- summaryFun(
   filterClean = FALSE)
 # Save the uncleaned dataset
 check_time %>% readr::write_excel_csv(.,
-                                paste(OutPath_Intermediate, "05_unCleaned_database.csv",
-                                      sep = "/"))
+                                paste(OutPath_Intermediate, "/05_unCleaned_database_",
+                                      Sys.Date(), ".csv",
+                                      sep = ""))
 
 ##### 8.3 Save cleaned ####
 # Now clean the dataset of extra columns and failed rows and save it...
@@ -1274,8 +1275,9 @@ cleanData <- BeeBDC::summaryFun(
 # Save this CLEANED dataset
 cleanData %>%
   readr::write_excel_csv(.,
-                   paste(OutPath_Intermediate, "05_cleaned_database.csv",
-                         sep = "/"))
+                         paste(OutPath_Intermediate, "/05_cleaned_database_",
+                               Sys.Date(), ".csv",
+                               sep = ""))
 # Dataset can be re-read here
     #  cleanData <-
     #    readr::read_csv(paste(OutPath_Intermediate, "05_cleaned_database.csv",
@@ -1428,11 +1430,11 @@ BeeBDC::interactiveMapR(
   lat = "decimalLatitude",
   # Occurrence dataset column with species names
   speciesColumn = "scientificName",
-  # Which species to map — a character vector of names or "ALL"
+  # Which species to map - a character vector of names or "ALL"
   # Note: "ALL" is defined AFTER filtering for country
   speciesList = "ALL",
   countryList = NULL, # studyArea
-  # Point jitter to see stacked points — jitters an amount in decimal degrees
+  # Point jitter to see stacked points - jitters an amount in decimal degrees
   jitterValue = 0.01
 )
 
